==> mongodb_3.2.11.orig.tar.gz: mongodb-src-r3.2.11/src/mongo/db/conn_pool_options.h <==
/**
 *    Copyright (C) 2014 MongoDB Inc.
 *
 *    This program is free software: you can redistribute it and/or  modify
 *    it under the terms of the GNU Affero General Public License, version 3,
 *    as published by the Free Software Foundation.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU Affero General Public License for more details.
 *
 *    You should have received a copy of the GNU Affero General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the GNU Affero General Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

namespace mongo {

// NOTE:
// The connection pools themselves are placed in different files and are currently hard to move
// due to spaghetti dependencies.
// TODO: Extract conn pools from driver files and shardconnection.cpp

/**
 * Struct namespace for connection pool options on mongos and mongod
 */
struct ConnPoolOptions {
    /**
     * Maximum connections per host the connection pool should use
     */
    static int maxConnsPerHost;

    /**
     * Maximum connections per host the sharded conn pool should use
     */
    static int maxShardedConnsPerHost;
};
}

==> mongodb_3.6.3.orig.tar.gz: mongodb-src-r3.6.3/src/mongo/db/conn_pool_options.h <==
/**
 *    Copyright (C) 2014 MongoDB Inc.
 *
 *    This program is free software: you can redistribute it and/or  modify
 *    it under the terms of the GNU Affero General Public License, version 3,
 *    as published by the Free Software Foundation.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU Affero General Public License for more details.
 *
 *    You should have received a copy of the GNU Affero General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the GNU Affero General Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include "mongo/util/duration.h"

namespace mongo {

// NOTE:
// The connection pools themselves are placed in different files and are currently hard to move
// due to spaghetti dependencies.
// TODO: Extract conn pools from driver files and shardconnection.cpp

/**
 * Struct namespace for connection pool options on mongos and mongod
 */
struct ConnPoolOptions {
    /**
     * Maximum connections per host the connection pool should store.
     */
    static int maxConnsPerHost;

    /**
     * Maximum connections per host the sharded conn pool should store.
     */
    static int maxShardedConnsPerHost;

    /**
     * Maximum in-use connections per host in the global connection pool.
     */
    static int maxInUseConnsPerHost;

    /**
     * Maximum in-use connections per host in the sharded connection pool.
     */
    static int maxShardedInUseConnsPerHost;

    /**
     * Amount of time, in minutes, to keep idle connections in the global connection pool.
     */
    static int globalConnPoolIdleTimeout;

    /**
     * Amount of time, in minutes, to keep idle connections in the sharded connection pool.
     */
    static int shardedConnPoolIdleTimeout;
};
}
